"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractRouter = void 0;
const lambda_router_1 = require("lambda-router");
class AbstractRouter {
    constructor(routerParams) {
        this.addResources = (resources) => {
            for (const resource of resources) {
                const { path } = resource;
                if (resource.get)
                    this.router.get(path, resource.get);
                if (resource.post)
                    this.router.post(path, resource.post);
                if (resource.put)
                    this.router.put(path, resource.put);
                if (resource.delete)
                    this.router.delete(path, resource.delete);
            }
        };
        this.route = (event, context) => {
            return this.router.route(event, context);
        };
        this.router = lambda_router_1.Router({
            logger: console,
            extractPathParameters: true,
            includeErrorStack: false,
            cors: false,
            parseBody: true,
            decodeEvent: true,
            normalizeHeaders: true,
            ...routerParams,
        });
        this.router.unknown(this.onUnknown);
        this.router.beforeRoute(this.obfuscateSecrets);
        this.router.beforeRoute(this.beforeRoute);
    }
    obfuscateSecrets(event, _context, _path, _method) {
        for (const header of Object.keys(event.headers)) {
            if (['authorization', 'x-api-key'].includes(header.toLowerCase())) {
                delete event.headers[header];
            }
        }
    }
}
exports.AbstractRouter = AbstractRouter;
